# didas

[PyPi Projekt](https://pypi.org/project/didas/)

## Installation

### PyPi

`pip install didas[mlflow,oracle]`

### GitHub

`pip install git+https://github.com/freenet-group/didas@main#egg=didas[mlflow,oracle]`

